#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_gluster_stats
----------------------------------

Tests for `gluster_stats` module.
"""
import hashlib
import json
import os
import shutil
from gluster_stats import gluster_stats
from builtins import object


class TestGlusterStats(object):
    """ Test gluster-stats """

    def test_378_default(self):
        """ Normal Run """
        stats = gluster_stats.GlusterStats(
                  test_file="tests/test_sources/gluster_stats_3.7.8.json")
        output = stats.get_stats()
        #print(json.dumps(output, indent=1, sort_keys=True))
        assert output == {
             "brick_stats": {
              "preprodcomms": [
               {
                "disk_free": 982151646412, 
                "disk_total": 1064615018496, 
                "inode_free": "206325202", 
                "inode_total": "208035840", 
                "online": 1
               }, 
               {
                "disk_free": 984191755878, 
                "disk_total": 1064615018496, 
                "inode_free": "206325528", 
                "inode_total": "208035840", 
                "online": 1
               }, 
               {
                "disk_free": 985802368614, 
                "disk_total": 1064615018496, 
                "inode_free": "206325083", 
                "inode_total": "208035840", 
                "online": 1
               }
              ]
             }, 
             "glusterd": 1, 
             "glusterfsd": 1, 
             "peers": 2, 
             "split_brain_entries": {
              "preprodcomms": 0
             }, 
             "unhealed_entries": {
              "preprodcomms": 855
             }, 
             "volumes": 1
            }

    def test_375_default(self):
        """ Normal Run """
        stats = gluster_stats.GlusterStats(
                  test_file="tests/test_sources/gluster_stats_3.7.5.json")
        output = stats.get_stats()
        #print(json.dumps(output, indent=1, sort_keys=True))
        assert output == {
             "brick_stats": {
              "u01gluster": [
               {
                "disk_free": 824204224102, 
                "disk_total": 824204224102, 
                "inode_free": "161060390", 
                "inode_total": "161060416", 
                "online": 1
               }, 
               {
                "disk_free": 824204224102, 
                "disk_total": 824204224102, 
                "inode_free": "161060390", 
                "inode_total": "161060416", 
                "online": 1
               }, 
               {
                "disk_free": 824204224102, 
                "disk_total": 824204224102, 
                "inode_free": "161060390", 
                "inode_total": "161060416", 
                "online": 1
               }
              ]
             }, 
             "glusterd": 1, 
             "glusterfsd": 1, 
             "peers": 2, 
             "split_brain_entries": {
              "u01gluster": 0
             }, 
             "unhealed_entries": {
              "u01gluster": 0
             }, 
             "volumes": 1
            }



#!/usr/bin/env python

from __future__ import print_function
import json
import subprocess

from builtins import object, str

PER_VOLUME_COMMANDS = [
    "gluster volume heal {0} info",
    "gluster volume heal {0} info split-brain",
    "gluster volume status {0} detail",
]

def execute(cmd):
    handle = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE)
    (stdout, stderr) = handle.communicate()
    return {'command': cmd, 'output': stdout+stderr}

def main():
    commands = []
    command = "gluster --version"
    commands.append(execute(command))

    gluster_version = commands[-1]['output'].split()[1]

    command = "gluster peer status"
    commands.append(execute(command))

    command = "gluster volume list"
    commands.append(execute(command))

    for volume in commands[-1]['output'].split():
        for command in PER_VOLUME_COMMANDS:
            output = execute(command.format(volume))
            if 'heal' in command:
                # Strip file list as they may be private data
                safe_output = []
                for line in output['output'].split('\n'):
                    if line.startswith("Number"):
                        safe_output.append(line)
                output['output'] = '\n'.join(safe_output)
            commands.append(output)

    command = "pidof glusterd"
    commands.append(execute(command))

    command = "pidof glusterfsd"
    commands.append(execute(command))

    output = {'gluster_version': gluster_version, 'commands': commands}
    with open("gluster_stats_{0}.json".format(gluster_version), 'w') as f:
        f.write(json.dumps(output, indent=4, sort_keys=True))

if __name__ == '__main__':
    main()
